# WSSiham-CLI

WSSiham CLI est un package écrit en python qui a pour but de manipuler les webservices de SIAHM.

C'est une alternative à l'utilisation du générateur [`phpro/soap-client`](https://github.com/phpro/soap-client) et à
[`siham-bakey`](https://git.univ-reunion.fr/sda-idfix/siham-bakery).

Les fonctionnalités de `wssiham` sont:
- activation / désactivation de l'accès à SIHAM HRA
  - Ajout / modification du login, de l'adresse mail à un matricule SIHAM

## Prérequis

- Python 3.9 minimum
- Un environnement virtuel : [`Pyenv`][pyenv], [`Virtualenv`][virtualenv] ou [`Conda`][conda]

## Installation

### Classique

- Récupérer le projet [`wssiham`](wssiham).

```console
git clone https://git.univ-reunion.fr/sda-misc/wssiham_py
cloning into 'wssiham' ...
---> 100%
Done
```

- Installer les modules neccessaires pour l'utilisation de l'application.

```console
$ pip install -r requirements.txt
---> 100%
Successfully installed zeep, PyYAML, requests, typer
```

- Utiliser le fichier `main-dev.py` pour lancer vos commandes.
  - **Exemple :** `python main.py --help`



### Poetry

Ldappy-Cli peut-être utiliser et installer via [`Poetry`](https://python-poetry.org/).

C'est un gestionnaire de package et de dépendance. C'est l'équivalent Python de `npm`.

Toutes les commandes sont disponibles directement sur le site de [`Poetry`](https://python-poetry.org/).

### Wheel

Vous pouvez directement installer le package `wssiham-cli` via le `wheel` disponible dans le dossier [dist](dist).

Pour l'installation :

```console
$ pip install wssiham-0.1.0-py3-none-any.whl
```

L'application possède une commande :
- `configuration` : gestion de l'authentification via les webservices;
- `hraaccount` : manipulation des comptes siham-hra (activation / désactivation /information).
- `extraction` : extraction de donnée sous forme de fichier **csv**.
- `indicateur` : récupèration d'indicateurs.

**Général**
```console
$ python main.py --help                                                                                                                                                            ✔  ldappy   10:29:14 
Usage: main-dev.py [OPTIONS] COMMAND [ARGS]...

Options:
  --version
  --verbose / --no-verbose  [default: no-verbose]
  --help                    Show this message and exit.

Commands:
  configuration  Conf WS siham
  extraction     Extraction
  hraaccount     Manipulation des comptes HRA SIHAM
  indicateur     Récupération d'indicateur SIHAM
```

### Fichier de configuration

Par défaut, le package `wssiham` possède les configurations pour s'authentifier sur les webservices des serveurs prod
et preprod de l'Université de la réunion

Vous pouvez aussi gérer les configurations directement via `configuration`.

```console
$ python main-dev.py configuration --help                                                                                                                     INT ✘  ws-siham   15:09:46 
Usage: main-dev.py configuration [OPTIONS] COMMAND [ARGS]...

  Configuration fichier webservices siham

Options:
  --help  Show this message and exit.

Commands:
  cat      Affiche le fichier de configuration par défaut
  create   Création d'un fichier de configuration du webservice SIHAM
  listing  Liste les fichiers de configuration existants
  load     Charge le fichier de configuration
  remove   Supprime un fichier de configuration
```

## Gestion des comptes siham

```console
$ python main.py rununivauthorization --help                                                                                                                                           ✔  ldappy   11:20:29 
Usage: main.py hraaccount [OPTIONS] COMMAND [ARGS]...

  Activation ou désactivation de compte HRA pour l'accès au selfservice de
  SIHAM

Options:
  --help  Show this message and exit.

Commands:
  create   Crée ou modifie l'accès HRA SIHAM à un user.
  disable  Désactive l'accès au selfservice de SIHAM pour un matricule...
  info     Récupère les informations, dont le login, associés à la liste...

```

### hraaccount

#### Activation

Pour ajouter ou modifier un login et une adresse mail (optionnel pour ce dernier), il faut avoir
le matricule siham de l'agent.

**Exemple**

- Ajouter le login "toto" et une adresse mail "toto@univ-reunion.fr" au matricule "RUN000200000"

```console
$ python main.py hraaccount create 'RUN000200000' 'toto' -m 'toto@univ-reunion.fr'
L'opération a été effectuée avec succès
```


#### Désactivation

Pour désactiver l'accès à Siham HRA à un agent, il faut avoir le matricule Siham de l'agent.

- Désactivation d'un utilisateur sur SIHAM HRA

```console
$ python main.py hraaccount disable 'RUN000200000'
L'opération a été effectuée avec succès
```

[pyenv]: https://github.com/pyenv/pyenv
[virtualenv]: https://github.com/pypa/virtualenv
[conda]: https://docs.conda.io/en/latest/
[ldappy]: https://git.univ-reunion.fr/sda-misc/ldappy
