import typer
from wssiham.core.liste_agents.recupListeAgents import RecupListeAgents
from wssiham.tools.typerExtend import TyperExtend
from rich.progress import Progress, SpinnerColumn, TextColumn, TimeElapsedColumn
import logging
import pandas as pd
import json
from pathlib import Path

logger = logging.getLogger(__name__)
app = typer.Typer()


def outfile_callback(outfile: str) -> str:
    if Path(outfile).suffix != "csv":
        raise typer.BadParameter("Le nom du fichier doit comporter l'extension .csv")
    if not Path(outfile).parent.exists():
        raise typer.BadParameter(f"Le dossier {Path(outfile).parent} n'existe pas")
    return outfile


@app.command()
def agents(outfile: str = typer.Argument(outfile_callback,
                                         help="nom du fichier exporter")):

    TyperExtend.simple_echo('Préparation de la récupération de la liste des agents de l\'Université de la Réunion')
    with Progress(
        SpinnerColumn(),
        TextColumn("[progress.description]{task.description}"),
        TimeElapsedColumn(),
        transient=False,
    ) as progress:
        progress.add_task(description="Récupération des données via le web service SIHAM ...",
                          total=None)
        recupla = RecupListeAgents(code_etablissement='9740478B')
        resp = recupla.response().model_dump()
    if recupla:
        TyperExtend.valid_echo(f"Données agents récupérer via le web service RecupListeAgents")
        data = json.loads(json.dumps(resp, default=str))

        TyperExtend.simple_echo('Préparation du fichier csv')
        pd.DataFrame(data)
        pd.DataFrame.from_dict(data)
        df = pd.DataFrame.from_records(data)
        df.to_csv(outfile, encoding='utf-8', index=False)
        TyperExtend.valid_echo(f"Le fichier \"{Path(outfile).name}\" a été créé dans le dossier "
                               f"\"{Path(outfile).resolve()}\"")
    else:
        TyperExtend.error_echo('Une erreur est survenue')
        TyperExtend.exit_unsuccess()

