from typing import List
from wssiham.core.siham_ws_ldap.userSiham import UserSiham
from wssiham.core.siham_ws_ldap.recupUserId import RecupUserId
from wssiham.tools.typerExtend import TyperExtend

from rich.progress import Progress, SpinnerColumn, TextColumn, TimeElapsedColumn
import logging
import typer

logger = logging.getLogger(__name__)
app = typer.Typer()


@app.command()
def create(matricule: str = typer.Argument(..., help="Matricule SIHAM à activer pour l'accès au selfservice "),
           login: str = typer.Argument(..., help="L'utilisateur recherché. \
                                                                Utilisation du dn ou du matricule siham."),
           mail: str = typer.Option("", "--mail", "-m", help="Mail de l'utilisateur."),
           usual_name: str = typer.Option("", "--usual-name", "-u", help="Nom usuel de l'utilisateur.")):
    """ Crée ou modifie l'accès HRA SIHAM à un user.
    Le matricule et le login sont obligatoires pour l'activation
    """

    TyperExtend.simple_echo('Préparation la création/modification de l\'accès HRA à '
                            f'l\'utilisateur matricule {matricule}')
    with Progress(
        SpinnerColumn(),
        TextColumn("[progress.description]{task.description}"),
        TimeElapsedColumn(),
        transient=False,
    ) as progress:
        progress.add_task(description="Utilisation du web service SIHAM ...", total=None)
        user = UserSiham(lognid=login, matcle=matricule, selfsrv=True, adusml=mail, nmprus=usual_name)

        result = user.create_or_modify()

    if result:
        TyperExtend.valid_echo("L'opération a été effectuée avec succès")
    else:
        TyperExtend.error_echo('L\'opération a été interrompu.')
        TyperExtend.info_echo(f' Vérifier que le matricule {matricule} existe.')
        TyperExtend.simple_echo(f'Voir sur crappy : https://crappy.univ-reunion.fr/activation/preview?id={matricule}')
        TyperExtend.exit_unsuccess()


@app.command()
def disable(matricule: str = typer.Argument(..., help="Matricule SIHAM dont l'accès au selfservice sera désactiver")):
    """ Désactive l'accès au selfservice de SIHAM pour un matricule donnée
    Le matricule est obligatoire pour la désactivation
    """

    user = UserSiham(lognid='', matcle=matricule, selfsrv=False)

    result = user.disable()
    if result:
        TyperExtend.valid_echo("L'opération a été effectuée avec succès")
    else:
        TyperExtend.error_echo('L\'opération a été interrompu.')
        TyperExtend.info_echo(f' Vérifier que le matricule {matricule} existe.')
        TyperExtend.simple_echo(f'Voir sur crappy : https://crappy.univ-reunion.fr/activation/preview?id={matricule}')
        TyperExtend.exit_unsuccess()


@app.command()
def info(matricules: str = typer.Argument(..., help="Matricules SIHAM dont on recherche le login")):
    """ Récupère les informations, dont le login, associés à la liste de matricule passé en paramètre
    Attention : Le webservice RecupUserID ne retourne pas pour les bonnes informations pour le moment
    """

    users = RecupUserId(matricules)
    result = users.response()
    if result:
        TyperExtend.simple_echo(result)
    else:
        TyperExtend.error_echo('L\'opération a été interrompu.')
        TyperExtend.exit_unsuccess()


