from wssiham.app.pec_doctorant.classes.doctorant import Doctorant
from dataclasses import dataclass, field
from wssiham.core.pec.priseEnChargeAgent import PriseEnChargeAgent
from datetime import datetime
from collections import defaultdict
import logging


logger = logging.getLogger(__name__)

uor = {'Centre de Recherche Juridique': 'HURC2F0000',
       'Océan Indien Espaces et Sociétés': 'HUR22J0000',
       'Centre dEconomie et Management de lOcéan Indien': 'HURC2E0000',
       'Déplacements, Identités, Regards, Ecritures': 'HURC2G0000',
       'Langues, textes et communications dans les espaces Créolophones et Francophones':	'HUEA1M3500',
       'ESPACE-DEV -Observation Spatiale, Modèles et Science Impliquée':	'HURC270000',
       'Physique et Ingénierie Mathématique pour l\'Energie et l\'environnemENT': 'HURC2C0000',
       'Institut Coopératif Austral de Recherche en Éducation': 'HUR22K0000',
       'Ingénierie, Recherche et Intervention, Sport, Santé et Environnement': 'HURC2H0000',
       'Centre d\'Etudes Périnatales de l\'Océan Indien': 'HURC2D0000',
       'Processus Infectieux en Milieu Insulaire Tropical': 'HURC240000',
       'Etudes en pharmaco-immunologie': 'HUR22P0000',
       'Peuplements Végétaux et Bioagresseurs en Milieux Tropicaux': 'HURC220000',
       'Laboratoire d\'Énergétique et d\'Électronique et Procédés': 'HUR22B0000',
       'Laboratoire dInformatique et Mathématiques': 'HUR21Z0000',
       # 'ASTRE - Animal, Santé, Territoires, Risques et Ecosystèmes': 'HUR0000000',           # pas dans SIHAM
       'Laboratoire de Chimie des Substances Naturelles et Sciences des Aliments': 'HURC2A0000',
       # 'Centre d\'Investigation Clinique 1410 La Réunion': 'HU00000000',                     # pas dans SIHAM
       'Diabète, Athérothrombose et Thérapies Réunion Océan Indien': 'HURC250000',
       'Écologie Marine Tropicale des Océans Pacifique et Indien': 'HURC230000',
       'Dynamique des Structures Systèmes et Interactions des Macromolécules Biologiques': 'HURC280000',
       'Laboratoire GéoSciences Réunion': 'HURC260000',
       'Laboratoire de l\'Atmosphère et des Cyclones': 'HURC210000',
       # 'Recyclage et Risque': 'HU00000000',                                                  # pas dans SIHAM
       'QualiSud': 'HURC290000'
      }

uo_recherche = defaultdict(lambda: 'HUR0000000', uor)

civi = {'Monsieur': '1', 'Madame': '2'}


@dataclass
class DoctorantSiham(Doctorant):
    """
    Class représentant un Doctorant dans SIHAM
    """

    date_embauche: str
    date_effet_statut: str
    date_effet_position: str
    date_effet_modalite: str
    date_fin_position: str = field(default='')
    civilite: str = field(init=False)
    sexe: str = field(init=False)
    uo: str = field(init=False)
    modalite: str = field(default='MS100')
    position: str = field(default='ACI01')
    statut: str = field(default='HB015')
    emploi: str = field(default='0000000000')
    code_administration: str = field(default='RUN')
    categorie_entree: str = field(default='ACTIVE')
    code_etablissement: str = field(default='9740478B')
    temoin_validite: str = field(default='4')

    temoin_injection: bool = field(default=False)     # Tentative d'injection
    date_injection: datetime = field(default=datetime.now())
    statut_injection: int = field(default=-1)         # 0 = fail (Erreur_general), 1 = ok (MAJ OK)

    def __post_init__(self):
        logger.debug("Initialisation de l'objet DoctorantSiham")

        # On prend en compte que le 1er prénom
        self.prenom = self.prenom.split()[0]

        if self.genre in civi.keys():
            self.civilite = civi[self.genre]
            self.sexe = civi[self.genre]
        if self.unite_recherche in uo_recherche.keys():
            self.uo = uo_recherche[self.unite_recherche]
        else:
            self.uo = 'HU00000000'

    def injection(self) -> None:
        """ Utilise le webservice PriseEnCharge de SIHAM pour injecter l'objet doctorantSiham dans ce référentiel
        """

        logger.debug(f"Injection du doctorant {self.nom} {self.prenom} dans SIHAM")
        doctorant = PriseEnChargeAgent(nom_usuel=self.nom, prenom=self.prenom, categorie_entree=self.categorie_entree,
                                       civilite=self.civilite,
                                       code_administration=self.code_administration,
                                       code_etablissement=self.code_etablissement, sexe=self.sexe,
                                       date_embauche=datetime.strptime(self.date_embauche, '%d/%m/%Y'),
                                       date_naissance=datetime.strptime(self.date_naissance, '%d/%m/%Y'),
                                       uo=self.uo, emploi=self.emploi,
                                       date_effet_statut=datetime.strptime(self.date_effet_statut, '%d/%m/%Y'),
                                       statut=self.statut,
                                       date_effet_position=datetime.strptime(self.date_effet_position, '%d/%m/%Y'),
                                       date_fin_prevue=datetime.strptime(self.date_fin_position, '%d/%m/%Y'),
                                       date_fin_reelle=datetime.strptime(self.date_fin_position, '%d/%m/%Y'),
                                       position=self.position,
                                       date_effet_modalite=datetime.strptime(self.date_effet_modalite, '%d/%m/%Y'),
                                       modalite='MS100', temoin_validite='4')
        resp = doctorant.response()
        if resp['statut'] == 'MAJ OK':
            logger.debug("L'injection a été réalisé avec succès")
            self.sihamid = resp['matricule']
            self.temoin_injection = True
            self.date_injection = datetime.now()
            self.statut_injection = 1
            self.crappy_url = f"https://crappy.univ-reunion.fr/activation/preview?id={resp['matricule']}"
        else:
            logger.debug("Un problème est survenu. L'injection a été annulé")
            logger.warning(f"Code erreur: {resp['statut']}")
            self.date_injection = datetime.now()
            self.statut_injection = 0

    def data_to_csv(self) -> str:
        """ Crée un msg (chaine de caractère) au format csv avec les différents attributs qui composent l'objet
        doctorantSiham

        Returns:
            Un message au format csv représentant le bordereau d'injection de l'objet doctorantSiham
        """
        return f'{self.nom},{self.prenom},{self.civilite},{self.sexe},{self.categorie_entree},' \
               f'{self.code_administration},{self.code_etablissement},{self.date_embauche},{self.date_naissance},' \
               f'{self.uo},{self.emploi},{self.date_effet_statut},{self.statut},{self.date_effet_position},' \
               f'{self.date_fin_position},{self.date_fin_position},{self.position},' \
               f'{self.date_effet_modalite},{self.modalite},{self.temoin_validite},{self.statut_injection}\n'

