from dataclasses import dataclass, field
from typing import Dict, Union
from datetime import datetime
from wssiham.connection.zeepclient import Zeepclient

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class ModifDonneesPersonnelles(Zeepclient):
    """Ce flux est mis en place pour permettre à des applications gérant le dossier du personnel de pouvoir apporter
    des modifications au niveau de SIHAM. Il donne la possibilité d’ajouter, de modifier ou de supprimer l’adresse
    personnelle et/ou l’adresse professionnelle et également ajouter ou supprimer l’affectation d’un agent.
    """
    matricule: str
    type_action: str                            # A : Ajout, M : Modification, S : Suppression
    type_adr_pers: str = field(default='')      # TAXX
    type_numero: str = field(default='')
    numero: str = field(default='')
    code_uo_affect_adresse: str = field(default='')

    code_etablissement: str = field(default='')
    code_pays: str = field(default='')
    code_postal: str = field(default='')
    no_voie: str = field(default='')
    bis_ter: str = field(default='')
    nom_voie: str = field(default='')
    nature_voie: str = field(default='')
    ville: str = field(default='')
    date_debut: str = field(default='')
    date_fin: str = field(default='')
    pourcentage_affectation: Union[int, None] = field(default=None)
    complement_adresse: str = field(default='')

    def response(self) -> str:
        """ Retourne le statut de la mise à jour "StatutMaj"
        - 1 : OK
        - 2 : KO

        Returns:
            Le nombre d'agent trouvé correspondant aux critres de sélection
        """
        try:
            resp = self.zeep_client.service.ModifDonneesPersonnelles(
                ParamModifDP=self.param_mfdp())
            if resp:
                result = zeep.helpers.serialize_object(resp)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result

    def param_mfdp(self) -> Dict[str, Union[str, int]]:

        parammfdp = {'bisTer': self.bis_ter,
                     'codeEtablissement': self.code_etablissement,
                     'codePays': self.code_pays,
                     'codePostal': self.code_postal,
                     'codeUOAffectAdresse': self.code_uo_affect_adresse,
                     'complementAdresse': self.complement_adresse,
                     'dateDebut': self.dd_datetime(),
                     'dateFin': self.df_datetime(),
                     'matricule': self.matricule,
                     'noVoie': self.no_voie,
                     'nomVoie': self.nom_voie,
                     'numero': self.numero,
                     'pourcentageAffectation': self.pourcentage_affectation,
                     'typeAction': self.type_action,
                     'typeAdrPers': self.type_adr_pers,
                     'typeNumero': self.type_numero,
                     'ville': self.ville}

        return parammfdp

    def dd_datetime(self) -> Union[datetime, str]:
        if self.date_debut:
            return datetime.strptime(self.date_debut, '%d/%m/%Y')
        return self.date_debut

    def df_datetime(self) -> Union[datetime, str]:
        if self.date_fin:
            return datetime.strptime(self.date_fin, '%d/%m/%Y')
        return self.date_fin
