from dataclasses import dataclass, field
from typing import List, Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_agent.recupDonneesAdministrativesResponse import InformationAdministrativeList
from wssiham.model.parametre.agent import ParamMatricule
from datetime import datetime

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupDonneesAdministratives(Zeepclient):
    """ L’objectif est de récuperer les données administratives des agents
    """
    liste_matricules: List[ParamMatricule]

    code_etablissement: str = field(default='')            # exemple : universite de la reunion = 9740478B
    date_observation: datetime = field(default='')         # format YYYY-MM-DD-HH.MM.SS
    date_fin_observation: datetime = field(default='')     # format YYYY-MM-DD-HH.MM.SS

    def response(self) -> List[Optional[InformationAdministrativeList]]:
        """ Récupere les données administratives de l'agent

        Returns:
            Liste contenant les informations administratives de l'agent recherché
                - La situation de carrière et contrat,
                - Les positions,
                - Les affectations,
                - Les modalités,
                - Les absences et congés,
                - Les PIP ,
                - Les notations,
                - Les services auxiliaires validés.

        """
        result = []
        try:
            resp = \
                self.zeep_client.service.RecupDonneesAdministratives(ParamListAgent=
                                                              {'codeEtablissement': self.code_etablissement,
                                                               'dateFinObservation': self.date_fin_observation,
                                                               'dateObservation': self.date_observation,
                                                               'listeMatricules': self.liste_matricules})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = InformationAdministrativeList(informationAdministrative=tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result
