from dataclasses import dataclass, field
from typing import List, Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_agent.recupDonneesHebergesResponse import InformationHebergeList
from wssiham.model.parametre.agent import ParamMatricule
from datetime import datetime

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupDonneesHeberges(Zeepclient):
    """ L’objectif de ce flux est d’envoyer des données pertinentes des agents hébergés.
    """
    liste_matricules: List[ParamMatricule]

    code_etablissement: str = field(default='')                 # exemple : universite de la reunion = 9740478B
    date_observation: datetime = field(default='')              # format YYYY-MM-DD-HH.MM.SS

    def response(self) -> List[Optional[InformationHebergeList]]:
        """ Récupere les données des agents hébergés.
        """
        result = []
        try:
            resp = \
                self.zeep_client.service.RecupDonneesHeberges(ParamListAgent=
                                                              {'codeEtablissement': self.code_etablissement,
                                                               'dateObservation': self.date_observation,
                                                               'listeMatricules': self.liste_matricules})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = InformationHebergeList(informationHeberge=tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result


