from dataclasses import dataclass, field
from typing import List, Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_agent.recupDonneesPersonnellesResponse import InformationPersonnelleList
from wssiham.model.parametre.agent import ParamMatricule
from datetime import datetime

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupDonneesPersonnelles(Zeepclient):
    """
L’objectif de ce flux est d’envoyer des données personnelles, d’un ou plusieurs agents
    """
    liste_matricules: List[ParamMatricule]

    code_etablissement: str = field(default='')                 # exemple : universite de la reunion = 9740478B
    date_observation: datetime = field(default='')       # format YYYY-MM-DD-HH.MM.SS
    date_fin_observation: datetime = field(default='')               # format YYYY-MM-DD-HH.MM.SS

    def response(self) -> List[Optional[InformationPersonnelleList]]:
        """ Récupere les données personnelles des agents.
        """
        result = []
        try:
            resp = \
                self.zeep_client.service.RecupDonneesPersonnelles(ParamListAgent=
                                                                  {'codeEtablissement': self.code_etablissement,
                                                                   'dateFinObservation': self.date_fin_observation,
                                                                   'dateObservation': self.date_observation,
                                                                   'listeMatricules': self.liste_matricules})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = InformationPersonnelleList(informationPersonnelle=tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result

