from dataclasses import dataclass, field
from typing import List, Union, Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_agent_date.recupDonneesAgentsResponse import DonneeAgentList
from wssiham.model.parametre.agent import ParamMatricule
from datetime import datetime

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupDonneesAgents(Zeepclient):
    """ Ce Web Service permet d’extraire l’exhaustivité des attributs de l’agent en vigueur ou non à la
    date d’observation.
    """
    liste_matricules: List[ParamMatricule]                                          # matricule de l'agent recherché
    date_observation: str = field(default='')               # format YYYY-MM-DD-HH.MM.SS

    def response(self) -> List[Optional[DonneeAgentList]]:
        """ Récupere l’exhaustivité des attributs de l’agent en vigueur ou non à la date d’obervation

        Returns:
            Liste contenant les données personnelles et professionnelles de l'agent


        """
        result = []
        try:
            resp = \
                self.zeep_client.service.RecupDonneesAgents(ParamAgentDateWS={'dateObservation': self.do_datetime(),
                                                                              'listeMatricules': self.liste_matricules})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = DonneeAgentList(donneeAgent=tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result

    def do_datetime(self) -> Union[datetime, str]:
        if self.date_observation:
            return datetime.strptime(self.date_observation, '%d/%m/%Y')
        return self.date_observation
