from dataclasses import dataclass, field
from typing import List, Union
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_parametrage.recupNomenclaturesRHResponse import NomenclatureList
from wssiham.model.parametre.nomenclature import ParamNomenclature
import zeep
import logging

logger = logging.getLogger(__name__)


@dataclass
class RecupNomenclaturesRH(Zeepclient):
    """ L’objectif de ce flux est d’exposer tout ou une partie de la nomenclature RH d’un établissement
    donné aux applications externes.
    """
    liste_nomenclatures: List[ParamNomenclature] = field(default='')

    code_administration: str = field(default='')                # 3 caractères (exemple: 'RUN' pour Université Réunion
    date_observation: str = field(default='')                   # format dd/mm/YYYY

    def __post_init__(self):
        super().__post_init__()
        if self.liste_nomenclatures is None and self.date_observation is None and self.code_administration is None:
            raise TypeError("Valeur requise pour au moins un champ.")

    def response(self) -> Union[NomenclatureList, List]:
        """ Récuperer les informations sur tous les répertoires du référentiel SIHAM

        Returns:
            Liste contenant les informations concernant les valeurs présentes dans le répertoire
            - Code de l’administration
            - Code du répertoire de la nomenclature
            - Code (valeur)
            - Date de début de validité
            - Date de fin de validité
            - Libellé long
            - Libellé court
            - Type de rémunération, paramétrage du PIP
            - Témoin Enseignant/ chercheur BIATSS, paramétrage Groupe Hiérarchique
            - Témoin Enseignant/ chercheur BIATSS, paramétrage PIP


        """
        result = []
        try:
            resp = \
                self.zeep_client.service.RecupNomenclaturesRH(ParamNomenclature=
                                                              {'dateObservation': self.date_observation,
                                                               'codeAdministration': self.code_administration,
                                                               'listeNomenclatures': self.liste_nomenclatures})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = NomenclatureList(nomenclatures=tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result



