from dataclasses import dataclass, field
from typing import List, Union, Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_parametrage.recupStructuresResponse import UniteOrganisationnelleList

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class UO:
    codeUO: str = field(default='')
    typeUO: str = field(default='')

    def __post_init__(self):
        if self.code_uo is None and self.type_uo:
            raise TypeError("Valeur requise pour au moins un champ.")


@dataclass
class RecupStructures(Zeepclient):
    """ Ce flux a pour objectif d’envoyer toutes les informations pertinentes sur les unités
    organisationnelles dans SIHAM.
    """
    liste_uo: Optional[List[UO]] = field(default='')
    code_administration: Optional[str] = field(default='')        # 3 caractères (exemple: 'RUN' pour Université Réunion)
    date_observation: Optional[str] = field(default='')                   # format dd/mm/YYYY

    def __post_init__(self):
        super().__post_init__()
        if self.liste_uo is None and self.code_administration is None and \
                self.date_observation is None:
            raise TypeError("Valeur requise pour au moins un champ.")

    def response(self) -> Union[UniteOrganisationnelleList, List]:
        """ Récuperer les données en vigueur à une date donnée pour une unité organisationnelle

        Returns:
            Liste contenant les informations sur les données d'une ou des unités organisationnelles

        """
        result = []
        try:
            resp = \
                self.zeep_client.service.RecupStructures(ParamStructure=
                                                         {'dateObservation': self.date_observation,
                                                          'codeAdministration': self.code_administration,
                                                          'listeUO': self.liste_uo})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = (UniteOrganisationnelleList(uniteOrganisationnelle=tmp_data))
                logger.debug(tmp_data)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result


