from dataclasses import dataclass, field
from typing import List, Union
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.liste_parametrage.genericStructureResponse import StructureEcheanceList

from datetime import datetime
import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupStructuresEcheance(Zeepclient):
    """ Ce WebService retourne les codes des structures organisationnelles dans SIHAM dont l’un des attributs échangés
    (Flux - Envoi des structures), gérés par date, entre en vigueur ou arrive à échéance entre les deux dates données
    """

    date_debut_observation: str = field(default='')               # format dd/mm/YYYY
    date_fin_observation: str = field(default='')
    found: tuple[bool, int] = \
        field(init=False, default=(False, -1), repr=False)  # tuple déterminant si un élément a été trouvé et son nombre

    def response(self) -> Union[StructureEcheanceList, List]:
        """ Retourne les codes des structures dont l’un des attributs échangés entre en vigueur ou
         arrive à échéance entre les deux dates données


        Returns:
            Liste contenant les informations concernant le (code structure, code Information, type UO, témoin État)

        """
        result = []
        try:
            if self.date_fin_observation:
                dateo = datetime.strptime(self.date_fin_observation, '%d/%m/%Y')
            else:
                dateo = self.date_fin_observation

            resp = \
                self.zeep_client.service.RecupStructuresEcheance(
                    ParamStructures={'dateDebutObservation': datetime.strptime(self.date_debut_observation, '%d/%m/%Y'),
                                     'dateFinObservation': dateo})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = StructureEcheanceList(structure_echeance=tmp_data)
                self.found = (True, len([ele for ele in result if isinstance(ele, dict)]))
            else:
                self.found = (False, 0)
                logger.debug('Aucun élément trouvé')
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result

