import typer
import sys
import logging
from pathlib import Path
sys.path.insert(0, str(Path.cwd().parent))
from wssiham.app import hraaccount, indicateursiham, conf, extraction, injection

__version__ = "1.1.3"

logger = logging.getLogger(__name__)


def version_callback(value: bool):
    if value:
        typer.echo(f"Wssiham CLI version: {__version__}")
        raise typer.Exit()


app = typer.Typer(add_completion=False)
app.add_typer(hraaccount.app,
              name='hraaccount',
              help="Activation ou désactivation de compte HRA pour l'accès au selfservice de SIHAM",
              short_help="Manipulation des comptes HRA SIHAM")

app.add_typer(indicateursiham.app,
              name='indicateur',
              help="Récupération d'indicateur SIHAM",
              short_help="Récupération d'indicateur SIHAM")

app.add_typer(conf.app,
              name='configuration',
              help="Configuration fichier webservices siham",
              short_help="Conf WS siham")

app.add_typer(extraction.app,
              name='extraction',
              help="Extraction de donnée",
              short_help="Extraction")

app.add_typer(injection.app,
              name='pec',
              help="prise en charge dans SIHAM",
              short_help="Pec")


@app.callback()
def main(
    version: bool = typer.Option(None, "--version", callback=version_callback, is_eager=True),
    verbose: bool = False
):
    if verbose:
        logging.getLogger('zeep').setLevel(logging.ERROR)
        logging.getLogger('urllib3').setLevel(logging.ERROR)

        logging.basicConfig(format='%(asctime)s :: %(name)s :: %(levelname)s :: %(message)s',
                            level=logging.DEBUG, handlers=[logging.StreamHandler()])


if __name__ == "__main__":
    app()
