from pydantic import BaseModel, conint, conlist, constr
from typing import Optional
from datetime import datetime


class InformationIndividuelBase(BaseModel):
    codeEtablissement: Optional[str]
    dateNaissance: datetime
    libLongCivilite: str
    matricule: str
    nomPatronymique: str
    nomUsuel: str
    prenom: str
    villeNaissance: Optional[str]


class InformationIndividuel(InformationIndividuelBase):
    """
    Modèle représentant les données personnelles d'une personne.
    """
    agenceCoordBanc: Optional[str]
    bisTerAdresse: Optional[str]
    bureauDistributeurAdresse: Optional[str]
    civilite: Optional[str]
    codeAdministration: Optional[str]
    codeDepartementAdresse: Optional[str]
    codePaysAdresseUO: Optional[str]
    codePaysCoordBanc: Optional[str]
    codePostalAdresseUO: Optional[str]
    codeSituationFamVigueur: Optional[str]
    codeUO: Optional[str]
    communeAdresseUO: Optional[str]
    complementAdresse: Optional[str]
    dateDeces: Optional[datetime]
    libLongDepartementAdresse: Optional[str]
    libLongPaysAdresseUO: Optional[str]
    libLongPaysNaissance: Optional[str]
    libLongSituationFamVigueur: Optional[str]
    localisationCoordBanc: Optional[str]
    noVoieAdresseUO: Optional[str]
    nomVoieAdresse: Optional[str]
    numDossierHarpege: str
    numen: Optional[str]
    numeroInseeDefinitif: Optional[str]
    numeroInseeProv: Optional[str]
    paysNaissance: Optional[str]
    typeAdresseUO: Optional[str]
    typeBanqueCoordBanc: Optional[str]


class InformationIndividuelDAD(InformationIndividuel):
    """
    Modèle représentant les données personnelles d'une personne.
    """
    BICIBAN1CoordBanc: str
    BICIBAN2CoordBanc: str
    BICIBAN3CoordBanc: str
    BICIBAN4CoordBanc: str
    BICIBAN5CoordBanc: str
    BICIBAN6CoordBanc: str
    BICIBAN7CoordBanc: str
    BICIBAN8CoordBanc: Optional[str]
    BICIBAN9CoordBanc: Optional[str]
    chevron: Optional[str]
    cleNir: str
    codeCorps: str
    codeCorpsOrigine: Optional[str]
    codeEchelon: str
    codeEchelonOrigine: Optional[str]
    codeGrade: str
    codeGradeOrigine: Optional[str]
    codeGroupeHierarchique: Optional[str]
    codeMotifPosition: str
    codeOrganismeOrigine: Optional[str]
    codePIP: str
    codePositionAdmin: str
    codePositionStatutaire: str
    codeQualiteStatutaire: str
    codeSortieAdministration: Optional[str]
    codeTypeContrat: Optional[str]
    dateDebutCarriereOrigine: Optional[datetime]
    dateDebutContrat: Optional[datetime]
    dateDebutPositionAdmin: datetime
    dateEffetCarriere: datetime
    dateEffetPIP: datetime
    dateEntreeAdministration: datetime
    dateEntreeCorps: Optional[datetime]
    dateEntreeGrade: Optional[datetime]
    dateFinCarriere: datetime
    dateFinCarriereOrigine: Optional[datetime]
    dateFinContrat: Optional[datetime]
    dateFinPrevueContrat: Optional[datetime]
    dateFinPrevuePositionAdmin: datetime
    dateFinReellePositionAdmin: datetime
    dateReferenceExtraction: datetime
    dateSortieAdministration: datetime
    dptNaissance: str
    frequencePayContrat: Optional[str]
    gradeTG: Optional[str]
    horsEchelleLettre: Optional[str]
    indiceMajore: conint(ge=0)
    indiceMajoreForce: conint(ge=0)
    indiceRemu: Optional[str]
    libCourtCorps: str
    libCourtCorpsOrigine: Optional[str]
    libLongAutreOrganisme: Optional[str]
    libLongCorps: str
    libLongCorpsOrigine: Optional[str]
    libLongDptNaissance: str
    libLongFreqPaiementContrat: Optional[str]
    libLongGrade: str
    libLongGradeOrigine: Optional[str]
    libLongGroupeHierarchique: Optional[str]
    libLongModeGestionContrat: Optional[str]
    libLongMotifPosition: str
    libLongOrganismeOrigine: Optional[str]
    libLongPIP: str
    libLongPositionAdmin: str
    libLongPositionStatutaire: str
    libLongQualiteStatutaire: str
    libLongSortieAdministration: Optional[str]
    libLongStatutOrigine: Optional[str]
    libLongTypeContrat: Optional[str]
    ligneAdresseVoieUO: Optional[str]
    modeGestContrat: Optional[str]
    modeRemuneration: Optional[str]
    natureContrat: Optional[str]
    natureVoieAdresseUO: Optional[str]
    nbHeuresContrat: Optional[float]
    nomPseudonyme: Optional[str]
    numeroAvenantContrat: Optional[str]
    numeroCarriere: str
    numeroDecision: str
    numeroOrdreCarriere: conint(ge=0)
    pourcentage: Optional[int]
    prenom1: Optional[str]
    prenom2: Optional[str]
    prenom3: Optional[str]
    prenom4: Optional[str]
    rangContrat: Optional[int]
    remunMensuelContrat: Optional[float]
    statutOrigine: Optional[str]
    tauxHoraireContrat: Optional[float]
    temEnseignantChercheur: str
    temEtat: str
    temHebergeRemunere: Optional[str]
    temRemuneration: str
    temValiditeCarriere: str
    temValiditeContrat: Optional[str]
    typeOrigine: Optional[str]


class InformationIndividuelDP(InformationIndividuel):
    codeBanqueCoordBanc: Optional[str]
    IBAN1CoordBanc: Optional[str]
    IBAN2CoordBanc: Optional[str]
    IBAN3CoordBanc: Optional[str]
    IBAN4CoordBanc: Optional[str]
    IBAN5CoordBanc: Optional[str]
    IBAN6CoordBanc: Optional[str]
    IBAN7CoordBanc: Optional[str]
    IBAN8CoordBanc: Optional[str]
    IBAN9CoordBanc: Optional[str]


class InformationIndividuelRA(BaseModel):
    codeCivilite: str


class InformationEnfant(BaseModel):
    matricule: str
    codeEtablissement: Optional[str]
    matriculEenfant: Optional[str]
    nomEnfant: Optional[str]
    prenomEnfant: Optional[str]
    dateNaissanceEnfant: Optional[datetime]
    natureParente: Optional[str]
    libLongNatureParente: Optional[str]
    codeSexeEnfant: Optional[str]
    libSexeEnfant: Optional[str]
    villeNaissanceEnfant: Optional[str]
    codeDptNaissanceEnfant: Optional[str]
    libLongDeptNaissanceEnfant: Optional[str]
    paysNaissanceEnfant: Optional[str]
    libLongPaysNaissanceEnfant: Optional[str]
    dateDecesEnfant: Optional[datetime]
    tauxHandicapEnfant: Optional[str]


class InformationHandicap(BaseModel):
    matricule: str
    codeEtablissement: Optional[str]
    motifHandicap: Optional[str]
    libLongHandicap: Optional[str]
    dateDebutHandicap: Optional[datetime]
    dateFinHandicap: Optional[datetime]
    tauxHandicap: Optional[str]


class Nationalite(BaseModel):
    codeNationalite: Optional[str]
    libLongNationalite: Optional[str]

